summaryrefslogtreecommitdiff
path: root/plugins/UserFlag/flagprofileform.php
diff options
context:
space:
mode:
authorEvan Prodromou <evan@status.net>2009-11-16 18:24:59 +0100
committerEvan Prodromou <evan@status.net>2009-11-16 18:24:59 +0100
commit55d00a3a907fa275a0df580a82cea20da95889c6 (patch)
treee97b67b6bafdda704a5dfbfd6d44d65b30751345 /plugins/UserFlag/flagprofileform.php
parentbea580873f10c186a3e12047c28d693d3dcb26d2 (diff)
make profile flag actions work like other profile actions
Diffstat (limited to 'plugins/UserFlag/flagprofileform.php')
-rw-r--r--plugins/UserFlag/flagprofileform.php96
1 files changed, 13 insertions, 83 deletions
diff --git a/plugins/UserFlag/flagprofileform.php b/plugins/UserFlag/flagprofileform.php
index a8396e2d5..262dad4a7 100644
--- a/plugins/UserFlag/flagprofileform.php
+++ b/plugins/UserFlag/flagprofileform.php
@@ -45,108 +45,38 @@ require_once INSTALLDIR.'/lib/form.php';
* @link http://status.net/
*/
-class FlagProfileForm extends Form
+class FlagProfileForm extends ProfileActionForm
{
/**
- * Profile of profile to flag
- */
-
- var $profile = null;
-
- /**
- * Return-to args
- */
-
- var $args = null;
-
- /**
- * Constructor
- *
- * @param HTMLOutputter $out output channel
- * @param Profile $profile profile of user to flag
- * @param array $args return-to args
- */
-
- function __construct($out=null, $profile=null, $args=null)
- {
- parent::__construct($out);
-
- $this->profile = $profile;
- $this->args = $args;
- }
-
- /**
- * ID of the form
- *
- * @return int ID of the form
- */
-
- function id()
- {
- return 'flagprofile-' . $this->profile->id;
- }
-
- /**
- * class of the form
+ * Action this form provides
*
- * @return string class of the form
+ * @return string Name of the action, lowercased.
*/
- function formClass()
+ function target()
{
- return 'form_entity_flag';
+ return 'flagprofile';
}
/**
* Action of the form
*
- * @return string URL of the action
+ * @return string Title of the form, internationalized
*/
- function action()
- {
- return common_local_url('flagprofile');
- }
-
- /**
- * Legend of the Form
- *
- * @return void
- */
- function formLegend()
+ function title()
{
- $this->out->element('legend', null, _('Flag profile for review'));
- }
-
- /**
- * Data elements of the form
- *
- * @return void
- */
-
- function formData()
- {
- // TODO: let the user choose a flag
-
- $this->out->hidden('flagprofileto-' . $this->profile->id,
- $this->profile->id,
- 'flagprofileto');
-
- if ($this->args) {
- foreach ($this->args as $k => $v) {
- $this->out->hidden('returnto-' . $k, $v);
- }
- }
+ return _('Flag');
}
/**
- * Action elements
+ * Description of the form
*
- * @return void
+ * @return string description of the form, internationalized
*/
- function formActions()
+ function description()
{
- $this->out->submit('submit', _('Flag'), 'submit', null, _('Flag profile for review'));
+ return _('Flag profile for review');
}
}
@@ -45,108 +45,38 @@ require_once INSTALLDIR.'/lib/form.php';
}
/**
- * Action of the form
+ * Title of the form
*